Changelog
==========

0.6.1
------

- Add support for custom user model

0.6.0
------

- Improve documentation
- Add unicode support at admin panel or shell

0.5.5
------

Support for arbitrary data attribute.

0.5.1
-----

Fix package descriptions and doc links.

0.5
-----

First version based on `django-activity-stream <https://github.com/justquick/django-activity-stream>`_ v0.4.3

